==> aimmo-0.69.19b542.tar.gz: aimmo-0.69.19b542/README.md <==
# Kurono (codename: aimmo)

[![Workflow Status](https://github.com/ocadotechnology/aimmo/actions/workflows/cicd.yml/badge.svg)](https://github.com/ocadotechnology/aimmo/actions/workflows/cicd.yml)
[![codecov](https://codecov.io/gh/ocadotechnology/aimmo/branch/master/graph/badge.svg)](https://codecov.io/gh/ocadotechnology/aimmo)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![Zenhub Shield](https://camo.githubusercontent.com/96347b1f6d9b0f08194ba026de8b69bc27bb8f0d/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f5368697070696e675f6661737465725f776974682d5a656e4875622d3565363062612e7376673f7374796c653d666c61742d737175617265)](https://app.zenhub.com/workspace/o/ocadotechnology/codeforlife-deploy-appengine/boards?repos=96999382,39072690)

<p align="center">
  <a href="https://www.codeforlife.education/play/kurono/" target="_blank">
      <img src="images/kurono_game.png" height="400px" alt="Kurono Game" />
  </a>
</p>

[Code for Life](https://www.codeforlife.education/) has been developed by Ocado Technology as a **free, open-source** project to inspire the next generation of computer scientists and to help teachers deliver the computing curriculum.

**Kurono** is a [Code for Life](https://www.codeforlife.education/) project, aimed at teaching students and keen adults programming with Python. The game is designed to be played in a class or a group setting, as it simulates a multiplayer online game.

We are open to contributors from anywhere around the world. Please read ahead if you'd like to get involved.

## To get started

- [Developer Guide](https://docs.codeforlife.education/developer-guide)

- [Good First Issues](https://github.com/ocadotechnology/aimmo/contribute)

- Setting up your work environment: [common setup](https://docs.codeforlife.education/git/common-setup) and [aimmo specific setup](https://docs.codeforlife.education/git/aimmo-setup)

- [Testing](https://docs.codeforlife.education/git/testing)

<p align="center">
  <br /><br />
  <a href="https://www.codeforlife.education/play/kurono/" target="_blank">
    <img src="images/kurono_logo_simple.svg" height="100px" alt="Kurono Logo" />
  </a>
</p>

==> aimmo-1.4.6b792.tar.gz: aimmo-1.4.6b792/README.md <==
# Kurono (codename: aimmo)

[![Workflow Status](https://github.com/ocadotechnology/aimmo/actions/workflows/cicd.yml/badge.svg)](https://github.com/ocadotechnology/aimmo/actions/workflows/cicd.yml)
[![codecov](https://codecov.io/gh/ocadotechnology/aimmo/branch/master/graph/badge.svg)](https://codecov.io/gh/ocadotechnology/aimmo)
[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen.svg?style=flat-square)](http://makeapullrequest.com)
[![Zenhub Shield](https://camo.githubusercontent.com/96347b1f6d9b0f08194ba026de8b69bc27bb8f0d/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f5368697070696e675f6661737465725f776974682d5a656e4875622d3565363062612e7376673f7374796c653d666c61742d737175617265)](https://app.zenhub.com/workspace/o/ocadotechnology/codeforlife-deploy-appengine/boards?repos=96999382,39072690)

<p align="center">
  <a href="https://www.codeforlife.education/play/" target="_blank">
      <img src="images/kurono_game.png" height="400px" alt="Kurono Game" />
  </a>
</p>

[Code for Life](https://www.codeforlife.education/) has been developed by Ocado Technology as a **free, open-source** project to inspire the next generation of computer scientists and to help teachers deliver the computing curriculum.

**Kurono** is a [Code for Life](https://www.codeforlife.education/) project, aimed at teaching students and keen adults programming with Python. The game is designed to be played in a class or a group setting, as it simulates a multiplayer online game.

We are open to contributors from anywhere around the world. Please read ahead if you'd like to get involved.

## To get started

- [Developer Guide](https://docs.codeforlife.education/developer-guide)

- [Good First Issues](https://github.com/ocadotechnology/aimmo/contribute)

- Setting up your work environment: [common setup](https://docs.codeforlife.education/git/common-setup) and [aimmo specific setup](https://docs.codeforlife.education/git/aimmo-setup)

- [Testing](https://docs.codeforlife.education/git/testing)

<p align="center">
  <br /><br />
  <a href="https://www.codeforlife.education/play/" target="_blank">
    <img src="images/kurono_logo_simple.svg" height="100px" alt="Kurono Logo" />
  </a>
</p>
